@@ -105,13 +105,7 @@ qx.Class.define("callbackery.Application", {
             });
 
             var blocker = root.getBlocker();
-            blocker.getBlockerElement().setStyles({
-                transition: 'opacity 0.2s'
-            });
             var desktopCoEl = desktopContainer.getContentElement();
-            desktopCoEl.setStyles({
-                transition: 'filter 0.2s'
-            });
             blocker.addListener('blocked',function(){
                 desktopCoEl.setStyles({
                     filter: 'blur(3px)',
